@@ -10,13 +10,12 @@ Dancer2::Debugger - Dancer2 panels for Plack::Debugger
 
 =head1 VERSION
 
-0.002
+0.003
 
 =cut
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
-use Carp;
 use Dancer2::Core::Types;
 use File::Spec;
 use JSON::MaybeXS;
@@ -127,7 +126,7 @@ has data_dir => (
     default => sub {
         my $dir = File::Spec->catfile( File::Spec->tmpdir, 'debugger_panel' );
         return $dir if ( -d $dir || mkdir $dir );
-        croak "Unable to create data_dir $dir: $!";
+        die "Unable to create data_dir $dir: $!";
     },
 );
 
